==> aplus_chat-0.0.2.tar.gz: lib/view/contact_info_view.dart <==
import 'dart:convert';

import 'package:aplus_chat/constants.dart';
import 'package:aplus_chat/core/services/web_services.dart';
import 'package:aplus_chat/global.dart';
import 'package:aplus_chat/helper/custom_styles.dart';
import 'package:aplus_chat/view/widgets/comman.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class ContactInfoView extends StatefulWidget {
  const ContactInfoView({
    Key? key,
    this.userId,
  }) : super(key: key);
  final String? userId;

  @override
  State<ContactInfoView> createState() => _ContactInfoViewState();
}

class _ContactInfoViewState extends State<ContactInfoView> {
  var userName = "".obs;
  var email = "".obs;
  var profilePicture = "".obs;

  @override
  void initState() {
    debugPrint(widget.userId);
    super.initState();
    if (widget.userId != null) {
      getOpponentUserProfileApi(widget.userId);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      body: SafeArea(
        child: Container(
          color: const Color(0xffE5E5EA),
          child: Column(
            children: [
              appBar(),
              Container(
                width: Get.width,
                color: Colors.white,
                child: Obx(
                  () => Padding(
                    padding: const EdgeInsets.only(
                        top: 26, left: 12, right: 12, bottom: 16),
                    child: Column(
                      children: [
                        Common.profileNetworkImage(
                          borderRadius: 200.0,
                          height: 200.0,
                          width: 200.0,
                          imageUrl: profilePicture.value,
                        ),
                        const SizedBox(height: 16),
                        Text(
                          userName.value,
                          style: CustomTextStyles.medium(
                              fontSize: 26.0, fontColor: Colors.black),
                          textAlign: TextAlign.center,
                        ),
                        Text(
                          email.value,
                          style: CustomTextStyles.normal(
                              fontSize: 20.0, fontColor: Colors.black),
                          textAlign: TextAlign.center,
                        ),
                      ],
                    ),
                  ),
                ),
              ),
              const SizedBox(height: 10),
            ],
          ),
        ),
      ),
    );
  }

  Widget appBar() {
    return Row(
      children: [
        IconButton(
            onPressed: () {
              Navigator.pop(context);
            },
            icon: const Icon(
              Icons.clear,
              size: 30.0,
            )),
        const SizedBox(
          width: 8,
        ),
        Text(
          "Contact Info",
          style:
              CustomTextStyles.medium(fontSize: 18.0, fontColor: Colors.black),
        ),
      ],
    );
  }

  var loadData = false.obs;
  getOpponentUserProfileApi(id) async {
    var body = {"secretKey": secKey, "userId": id};
    Webservice.postRequest(
      uri: Global.getUserDetails,
      body: body,
      baseUrl: Global.baseApiUrl,
      hasBearer: false,
      onSuccess: (response) {
        loadData.value = false;
        var res = jsonDecode(response);
        userName.value = res['item']['username'];
        email.value = res['item']['email'];
        profilePicture.value = res['item']['profilePicture'];
      },
      onFailure: (v) {
        loadData.value = false;
      },
    );
  }
}

==> aplus_chat-0.1.7.tar.gz: lib/view/contact_info_view.dart <==
import 'dart:convert';
import 'package:aplus_chat/core/services/web_services.dart';
import 'package:aplus_chat/global.dart';
import 'package:aplus_chat/helper/custom_styles.dart';
import 'package:aplus_chat/helper/storages.dart';
import 'package:aplus_chat/view/widgets/comman.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class ContactInfoView extends StatefulWidget {
  const ContactInfoView({
    Key? key,
    this.userId,
  }) : super(key: key);
  final String? userId;

  @override
  State<ContactInfoView> createState() => _ContactInfoViewState();
}

class _ContactInfoViewState extends State<ContactInfoView> {
  var userName = "".obs;
  var email = "".obs;
  var profilePicture = "".obs;

  @override
  void initState() {
    debugPrint(widget.userId);
    super.initState();
    if (widget.userId != null) {
      getOpponentUserProfileApi(widget.userId);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      body: SafeArea(
        child: Container(
          color: const Color(0xffE5E5EA),
          child: Column(
            children: [
              appBar(),
              Container(
                width: Get.width,
                color: Colors.white,
                child: Obx(
                  () => Padding(
                    padding: const EdgeInsets.only(
                        top: 26, left: 12, right: 12, bottom: 16),
                    child: Column(
                      children: [
                        Common.profileNetworkImage(
                          borderRadius: 200.0,
                          height: 200.0,
                          width: 200.0,
                          imageUrl: profilePicture.value,
                        ),
                        const SizedBox(height: 16),
                        Text(
                          userName.value,
                          style: CustomTextStyles.medium(
                              fontSize: 26.0, fontColor: Colors.black),
                          textAlign: TextAlign.center,
                        ),
                        Text(
                          email.value,
                          style: CustomTextStyles.normal(
                              fontSize: 20.0, fontColor: Colors.black),
                          textAlign: TextAlign.center,
                        ),
                      ],
                    ),
                  ),
                ),
              ),
              const SizedBox(height: 10),
            ],
          ),
        ),
      ),
    );
  }

  Widget appBar() {
    return Row(
      children: [
        IconButton(
            onPressed: () {
              Navigator.pop(context);
            },
            icon: const Icon(
              Icons.clear,
              size: 30.0,
            )),
        const SizedBox(
          width: 8,
        ),
        Text(
          "Contact Info",
          style:
              CustomTextStyles.medium(fontSize: 18.0, fontColor: Colors.black),
        ),
      ],
    );
  }

  var loadData = false.obs;
  getOpponentUserProfileApi(id) async {
    var body = {"secretKey": AppStorages.secKey, "userId": id};
    Webservice.postRequest(
      uri: Global.getUserDetails,
      body: body,
      baseUrl: Global.baseApiUrl,
      hasBearer: false,
      onSuccess: (response) {
        loadData.value = false;
        var res = jsonDecode(response);
        userName.value = res['item']['username'];
        email.value = res['item']['email'];
        profilePicture.value = res['item']['profilePicture'];
      },
      onFailure: (v) {
        loadData.value = false;
      },
    );
  }
}
